@@ -26,6 +26,7 @@ from .rot18 import Rot18
 from .rot47 import Rot47
 from .rot5 import Rot5
 from .scytale import Scytale
+from .spiral import Spiral
 from .three_square import ThreeSquare
 from .trifid import Trifid
 from .two_square import TwoSquare
@@ -39,6 +40,6 @@ __all__ = [
     "Chao", "ColumnarTransposition", "FourSquare", "Gronsfeld",
     "Keyword", "MyszkowskiTransposition",
     "Nihilist", "SimpleSubstitution", "Playfair", "Porta", "Polybius",
-    "Rot13", "Rot18", "Rot47", "Rot5", "Scytale", "ThreeSquare",
+    "Rot13", "Rot18", "Rot47", "Rot5", "Scytale", "Spiral", "ThreeSquare",
     "Trifid", "TwoSquare", "Vigenere", "Vic", "Zigzag",
 ]
