@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # -*- encoding: utf-8 -*-
-
-import secretpy.alphabets as al
+from itertools import starmap
 from .polybius_square import PolybiusSquare
+import secretpy.alphabets as al
 
 
 class Polybius:
@@ -10,7 +10,7 @@ class Polybius:
     The Polybius Cipher
     """
 
-    def encrypt(self, text, key="", alphabet=al.ENGLISH_SQUARE_IJ):
+    def encrypt(self, text, key=None, alphabet=al.ENGLISH_SQUARE_IJ):
         """
         Encryption method
 
@@ -25,15 +25,13 @@ class Polybius:
         :rtype: string
         """
         square = PolybiusSquare(alphabet, key)
-        header = list(map(str, range(1, square.get_columns() + 1)))
         res = []
-        for t in text:
-            row, column = square.get_coordinates(t)
-            res.append(header[row])
-            res.append(header[column])
+        for row, column in map(square.get_coordinates, text):
+            res.append(str(row + 1))
+            res.append(str(column + 1))
         return "".join(res)
 
-    def decrypt(self, text, key="", alphabet=al.ENGLISH_SQUARE_IJ):
+    def decrypt(self, text, key=None, alphabet=al.ENGLISH_SQUARE_IJ):
         """
         Decryption method
 
@@ -48,18 +46,8 @@ class Polybius:
         :rtype: string
         """
         square = PolybiusSquare(alphabet, key)
-        header = list(map(str, range(1, square.get_columns() + 1)))
-        res = []
-        for i in range(1, len(text), 2):
-            try:
-                row = header.index(text[i-1])
-            except ValueError:
-                wrchar = text[i-1].encode('utf-8')
-                raise Exception("Can't find char '" + wrchar + "' of text in alphabet!")
-            try:
-                column = header.index(text[i])
-            except ValueError:
-                wrchar = text[i].encode('utf-8')
-                raise Exception("Can't find char '" + wrchar + "' of text in alphabet!")
-            res.append(square.get_char(row, column))
-        return "".join(res)
+        it = iter(map(lambda t: int(t) - 1, text))
+        return "".join(starmap(square.get_char, zip(it, it)))
+
+    def get_crypt_alphabet(self):
+        return al.DECIMAL
